==> haskell-hslua-aeson-2.3.1.1-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-aeson
version:              2.3.1.1
visibility:           public
id:                   hslua-aeson-2.3.1.1-61ZjgPYcGMjA2Zz0xwLgUZ
key:                  hslua-aeson-2.3.1.1-61ZjgPYcGMjA2Zz0xwLgUZ
license:              MIT
copyright:            © 2017–2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  b3761b9a9c6e5ea3d33238c19d11ae14
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.3.1.1-61ZjgPYcGMjA2Zz0xwLgUZ
depends:
    aeson-2.1.2.1-AErwMfn2r5g1Pc6FekWoJb base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.6.0-HNsjIjcKtfz4EPsBV3Crzv
    hslua-core-2.3.2-BFTlhHliVgbH4hFQ3vhP9Q
    hslua-marshalling-2.3.1-FMzMiQvPoRN4lywxRQScdl mtl-2.2.2
    scientific-0.3.8.0-Hcx0Ig8vfV6K9QIlykOJmr text-2.0.2
    unordered-containers-0.2.20-2t1vPVJZrFoJrApu3o7oBM
    vector-0.13.2.0-ALyKXv7XVpOIl9EVBdgwIc

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-aeson-2.3.1.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-aeson
version:              2.3.1.1
visibility:           public
id:                   hslua-aeson-2.3.1.1-LBbDi6s4wBS6X1hg12XTDy
key:                  hslua-aeson-2.3.1.1-LBbDi6s4wBS6X1hg12XTDy
license:              MIT
copyright:            © 2017–2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  251a5c4ff0529ed011cc589cd361c1c2
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.3.1.1-LBbDi6s4wBS6X1hg12XTDy
depends:
    aeson-2.1.2.1-6h5MFvBT17H5yplsTy4ABm base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-GgneweRn8eTKcMM4X3n956
    hslua-core-2.3.2-3ZNZpl1DyQ3BUvHE8s68wi
    hslua-marshalling-2.3.1-I8HuDIpHkWP4ln6JJadrpK mtl-2.2.2
    scientific-0.3.8.0-3KgWCwEWnxjIUGX8ssH1BR text-2.0.2
    unordered-containers-0.2.20-2N1fR83O3bC5qS2nrjaL2B
    vector-0.13.2.0-EQFZws9ZIK8A2ESM3MR23n

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
